@@ -1,27 +1,33 @@
-// $Id: Box.h,v 1.5 1995/05/17 18:43:48 zeller Exp $
+// $Id: Box.h,v 1.11 1997/04/25 06:34:40 zeller Exp $
 // Klasse Box (Deklaration)
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free
-// Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// License along with the DDD Library -- see the file COPYING.LIB.
+// If not, write to the Free Software Foundation, Inc.,
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// 
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_Box_h
-#define _Nora_Box_h
+#ifndef _DDD_Box_h
+#define _DDD_Box_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -159,6 +165,9 @@ public:
     // Copy box
     virtual Box *dup() const = 0;
 
+    // Same, but only one level deep (if possible)
+    virtual Box *dup0() const { return dup(); }
+
     // Kill reference
     void unlink()
     {
@@ -196,7 +205,7 @@ public:
     virtual Box* resize() { return this; }
 
     // Propagate new font
-    virtual void newFont(const string& font) { resize(); }
+    virtual void newFont(const string&) { resize(); }
 
     // Draw
     void draw(Widget w, 
@@ -206,7 +215,6 @@ public:
 	      GC gc = 0, 
 	      bool context_selected = false) const;
 
-
     // Print box; Header/trailer must be pre-/postfixed
     virtual void _print(ostream& os, 
 			const BoxRegion& region, 
@@ -254,19 +262,23 @@ public:
     bool selected(BoxPoint p = BoxPoint(-1,-1)) const;   // Flag: selected?
     string info(BoxPoint p = BoxPoint(-1,-1)) const;        // Debugging info
 
-    // return the box that is to be matched
+    // Return the box that is to be matched
     virtual const Box& matchMe() const { return *this; }
 
     // Search functions
 
     // Count MatchBoxes
-    virtual void countMatchBoxes(int instances[]) const {}
+    virtual void countMatchBoxes(int[]) const {}
 
     // Return TagBox for a point (No Punkt: outermost)
-    virtual const TagBox *findTag(BoxPoint p = BoxPoint(-1, -1)) const 
+    virtual const TagBox *findTag(const BoxPoint&) const 
     { 
 	return 0;
     }
+    const TagBox *findTag() const
+    {
+	return findTag(BoxPoint(-1, -1));
+    }
 
     // Debugging
     // Send box to stream
@@ -281,5 +293,5 @@ public:
     }
 };
 
-#endif // _Nora_Box_h
+#endif // _DDD_Box_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
