@@ -1,31 +1,33 @@
-// $Id: GraphEdit.h,v 1.3 1995/05/17 18:44:29 zeller Exp $
+// $Id: GraphEdit.h,v 1.15 1997/04/25 06:36:23 zeller Exp $
 // GraphEdit Widget -- public interface
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_GraphEdit_h
-#define _Nora_GraphEdit_h
+#ifndef _DDD_GraphEdit_h
+#define _DDD_GraphEdit_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -46,6 +48,7 @@
 #define XtNshowHints                "showHints"
 #define XtNhintSize                 "hintSize"
 #define XtNopaqueMove               "opaqueMove"
+#define XtNautoRaise                "autoRaise"
 #define XtNgridWidth                "gridWidth"
 #define XtNgridHeight               "gridHeight"
 #define XtNextraWidth               "extraWidth"
@@ -68,52 +71,75 @@
 #define XtNselectionChangedCallback "selectionChanged"
 #define XtNsizeChangedCallback      "sizeChanged"
 #define XtNcompareNodesCallback     "compareNodes"
+#define XtNpreLayoutCallback        "preLayout"
+#define XtNpostLayoutCallback       "postLayout"
 #define XtNselectTile               "selectTile"
 #define XtNrotation		    "rotation"
 #define XtNautoLayout		    "autoLayout"
 #define XtNnodeColor                "nodeColor"
 #define XtNedgeColor                "edgeColor"
 #define XtNframeColor               "frameColor"
+#define XtNoutlineColor             "outlineColor"
 #define XtNgridColor                "gridColor"
 #define XtNselectColor              "selectColor"
+#define XtNselfEdgeDiameter         "selfEdgeDiameter"
+#define XtNselfEdgePosition         "selfEdgePosition"
+#define XtNselfEdgeDirection        "selfEdgeDirection"
 
 
 
 // Class types
 
-#define XtCGraph     	   "Graph"
-#define XtCMoveDelta       "MoveDelta"
-#define XtCRubberEdges     "RubberEdges"
-#define XtCRubberArrows    "RubberArrows"
-#define XtCShowHints       "ShowHints"
-#define XtCHintSize        "HintSize"
-#define XtCOpaqueMove      "OpaqueMove"
-#define XtCGridWidth       "GridWidth"
-#define XtCGridHeight      "GridHeight"
-#define XtCExtraWidth      "ExtraWidth"
-#define XtCExtraHeight     "ExtraHeight"
-#define XtCShowGrid        "ShowGrid"
-#define XtCSnapToGrid      "SnapToGrid"
-#define XtCEdgeWidth       "EdgeWidth"
-#define XtCEdgeAttachMode  "EdgeAttachMode"
-#define XtCLayoutMode      "LayoutMode"
-#define XtCArrowAngle	   "ArrowAngle"
-#define XtCArrowLength	   "ArrowLength"
-#define XtCRotation	   "Rotation"
-#define XtCAutoLayout	   "AutoLayout"
+#define XtCGraph     	     "Graph"
+#define XtCMoveDelta         "MoveDelta"
+#define XtCRubberEdges       "RubberEdges"
+#define XtCRubberArrows      "RubberArrows"
+#define XtCShowHints         "ShowHints"
+#define XtCHintSize          "HintSize"
+#define XtCOpaqueMove        "OpaqueMove"
+#define XtCAutoRaise         "AutoRaise"
+#define XtCGridSize          "GridSize"
+#define XtCExtraSize         "ExtraSize"
+#define XtCShowGrid          "ShowGrid"
+#define XtCSnapToGrid        "SnapToGrid"
+#define XtCEdgeWidth         "EdgeWidth"
+#define XtCEdgeAttachMode    "EdgeAttachMode"
+#define XtCLayoutMode        "LayoutMode"
+#define XtCArrowAngle	     "ArrowAngle"
+#define XtCArrowLength	     "ArrowLength"
+#define XtCRotation	     "Rotation"
+#define XtCAutoLayout	     "AutoLayout"
+#define XtCSelfEdgeDiameter  "SelfEdgeDiameter"
+#define XtCSelfEdgePosition  "SelfEdgePosition"
+#define XtCSelfEdgeDirection "SelfEdgeDirection"
 
 
 // Representation types
 
-#define XtREdgeAttachMode  "EdgeAttachMode"
-#define XtRLayoutMode      "LayoutMode"
+#define XtREdgeAttachMode    "EdgeAttachMode"
+#define XtRLayoutMode        "LayoutMode"
+#define XtRSelfEdgePosition  "SelfEdgePosition"
+#define XtRSelfEdgeDirection "SelfEdgeDirection"
 
 
-// declare specific GraphEdit class and instance datatypes
+// Declare specific GraphEdit class and instance datatypes
 typedef struct _GraphEditClassRec *GraphEditWidgetClass;
 typedef struct _GraphEditRec      *GraphEditWidget;
 
 
+// Modes
+enum LayoutMode {
+    RegularLayoutMode,		// Use regular Sugiyama/Misue layout method
+    CompactLayoutMode		// Use a more compact alternative
+};
+
+enum SelectionMode { 
+    SetSelection,		// Set the selection
+    ExtendSelection,		// Extend the selection
+    ToggleSelection		// Toggle the selection
+};
+
+
 // Callback Infos
 struct GraphEditPositionChangedInfo {
     Graph     *graph;          // Graph this node is in
@@ -134,7 +160,7 @@ struct GraphEditPositionChangedInfo {
 };
 
 struct GraphEditSelectionChangedInfo {
-    Graph     *graph;          // Graph this node is in
+    Graph     *graph;		// Graph this node is in
 
     GraphEditSelectionChangedInfo():
         graph(0)
@@ -144,11 +170,24 @@ struct GraphEditSelectionChangedInfo {
     {}
 };
 
+struct GraphEditLayoutInfo {
+    Graph     *graph;		// Graph this node is in
+    LayoutMode mode;		// Current layout mode
+    int rotation;		// Rotation (in degrees)
+
+    GraphEditLayoutInfo():
+        graph(0), mode(RegularLayoutMode), rotation(0)
+    {}
+    GraphEditLayoutInfo(const GraphEditLayoutInfo& info):
+        graph(info.graph), mode(info.mode), rotation(info.rotation)
+    {}
+};
+
 struct GraphEditCompareNodesInfo {
-    Graph     *graph;          // Graph these nodes are in
-    GraphNode *node1;	       // Nodes to compare
+    Graph     *graph;		// Graph these nodes are in
+    GraphNode *node1;		// Nodes to compare
     GraphNode *node2;
-    int       result;          // Compare result (read/write; < 0, 0, > 0)
+    int       result;		// Compare result (read/write; < 0, 0, > 0)
 
     GraphEditCompareNodesInfo():
         graph(0),
@@ -165,16 +204,10 @@ struct GraphEditCompareNodesInfo {
 };
 
 
-// Modes
-enum LayoutMode {
-    RegularLayoutMode,	// use regular Sugiyama/Misue layout method
-    CompactLayoutMode 	// use a more compact alternative
-};
-
-// declare the class constant
+// Declare the class constant
 extern WidgetClass graphEditWidgetClass;
 
-// declare special access functions
+// Declare special access functions
 
 // Inform widget that its size has changed
 extern void graphEditSizeChanged(Widget w);
@@ -197,4 +230,14 @@ extern void graphEditRedraw(Widget w);
 // Redraw a single node
 extern void graphEditRedrawNode(Widget w, GraphNode *node);
 
-#endif
+// Raise a single node
+extern void graphEditRaiseNode(Widget w, GraphNode *node);
+
+// Return final position (if snapToGrid is enabled, for example)
+extern BoxPoint graphEditFinalPosition(Widget w, const BoxPoint& p);
+
+// Disable or enable display
+extern Boolean graphEditEnableRedisplay(Widget w, Boolean state);
+
+#endif // _DDD_GraphEdit_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
