@@ -1,31 +1,33 @@
-// $Id: GraphGC.h,v 1.3 1995/05/17 18:44:33 zeller Exp $
+// $Id: GraphGC.h,v 1.11 1997/04/25 06:36:26 zeller Exp $
 // Graph graphics context
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_GraphGC_h
-#define _Nora_GraphGC_h
+#ifndef _DDD_GraphGC_h
+#define _DDD_GraphGC_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -36,17 +38,30 @@
 #include "Box.h"
 #include "TypeInfo.h"
 
-
+// Where to attach edges
 enum EdgeAttachMode {
     Straight,	// attach edge on nearest edge point
     Circle,     // ...but assume nodes to be displayed as circles
     Centered    // attach edge on center of node edge
 };
 
+// Where to attach edges pointing at self
+enum SelfEdgePosition {
+    NorthEast,			// Upper right corner
+    SouthEast,			// Lower right corner
+    NorthWest,			// Upper left corner
+    SouthWest			// Lower left corner
+};
+
+// How to align edges pointing at self
+enum SelfEdgeDirection { Clockwise, Counterclockwise };
+
 struct GraphGC {
     DECLARE_TYPE_INFO
 
     // Drawing stuff
+    bool           redraw;	     // Redraw only marked nodes?
+
     GC             nodeGC;           // X Graphics context for nodes
     GC             hintGC;           // X Graphics context for hints
     GC             edgeGC;           // X Graphics context for edges
@@ -55,12 +70,16 @@ struct GraphGC {
 
     BoxPoint       offsetIfSelected; // Offset to apply if nodes are selected
     EdgeAttachMode edgeAttachMode;   // Where to attach edges
-    bool        drawArrowHeads;   // Flag: draw arrow heads?
-    bool        drawHints;        // Flag: draw hints?
+    bool           drawArrowHeads;   // Flag: draw arrow heads?
+    bool           drawHints;        // Flag: draw hints?
     BoxCoordinate  hintSize;         // Hint size (in pixels)
     unsigned       arrowAngle;       // Arrow angle (in degrees)
     unsigned       arrowLength;      // Arrow length (in pixels)
 
+    BoxCoordinate     selfEdgeDiameter;  // Diameter of edge pointing at self
+    SelfEdgePosition  selfEdgePosition;  // Its position relative to the node
+    SelfEdgeDirection selfEdgeDirection; // Its direction
+
     // Printing stuff
     BoxPrintGC     *printGC;               // Graphics context for printing
     bool        printSelectedNodesOnly; // Flag: print selected nodes only?
@@ -69,6 +88,7 @@ struct GraphGC {
 
     // Default Constructor
     GraphGC(GC n = 0, GC e = 0, GC i = 0, GC c = 0):
+	redraw(false),
         nodeGC(n),
         hintGC(n),
         edgeGC(e),
@@ -81,12 +101,16 @@ struct GraphGC {
         hintSize(8),
         arrowAngle(30),
         arrowLength(10),
+	selfEdgeDiameter(32),
+	selfEdgePosition(NorthEast),
+	selfEdgeDirection(Counterclockwise),
 	printGC(&defaultPrintGC),
 	printSelectedNodesOnly(false)
     {}
 
     // Copy Constructor
     GraphGC(const GraphGC& g):
+	redraw(g.redraw),
         nodeGC(g.nodeGC),
         hintGC(g.hintGC),
         edgeGC(g.edgeGC),
@@ -99,9 +123,13 @@ struct GraphGC {
         hintSize(g.hintSize),
         arrowAngle(g.arrowAngle),
         arrowLength(g.arrowLength),
+	selfEdgeDiameter(g.selfEdgeDiameter),
+	selfEdgePosition(g.selfEdgePosition),
+	selfEdgeDirection(g.selfEdgeDirection),
 	printGC(g.printGC),
 	printSelectedNodesOnly(g.printSelectedNodesOnly)
     {}
 };
 
-#endif
+#endif // _DDD_GraphGC_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
