@@ -1,31 +1,33 @@
-// $Id: HintGraphN.h,v 1.3 1995/05/17 18:44:39 zeller Exp $  -*- C++ -*-
+// $Id: HintGraphN.h,v 1.10 1997/04/25 06:36:38 zeller Exp $  -*- C++ -*-
 // HintGraphNode class
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_HintGraphNode_h
-#define _Nora_HintGraphNode_h
+#ifndef _DDD_HintGraphNode_h
+#define _DDD_HintGraphNode_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -42,11 +44,25 @@ protected:
 			   const BoxRegion& exposed,
 			   const GraphGC& gc) const;
 
+    // Copy Constructor
+    HintGraphNode(const HintGraphNode &node):
+	RegionGraphNode(node)
+    {}
+
 public:
-    HintGraphNode(BoxPoint& initialPos = BoxPoint()):
+    // Constructor
+    HintGraphNode(const BoxPoint& initialPos = BoxPoint()):
        RegionGraphNode(initialPos, BoxSize(0,0))
     {}
 
+    // Destructor
+    virtual ~HintGraphNode() {}
+
+    GraphNode *dup() const
+    {
+	return new HintGraphNode(*this);
+    }
+
     virtual bool isHint() const { return true; }
 
     virtual const BoxRegion& region(const GraphGC& gc) const
@@ -67,5 +83,5 @@ public:
     }
 };
 
-#endif // _Nora_HintGraphNode_h
+#endif // _DDD_HintGraphNode_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
