@@ -1,31 +1,33 @@
-// $Id: LiterateA.h,v 1.4 1995/05/18 19:04:19 zeller Exp $
+// $Id: LiterateA.h,v 1.12 1997/04/25 06:36:54 zeller Exp $
 // Agent interface on a callback basis
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_LiterateAgent_h
-#define _Nora_LiterateAgent_h
+#ifndef _DDD_LiterateAgent_h
+#define _DDD_LiterateAgent_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -79,11 +81,7 @@ public:
     DECLARE_TYPE_INFO
 
 private:
-    void _outputException();	// exception on output channel
-    void _inputException();	// exception on input channel
-    void _errorException();	// exception on error channel
-
-    bool activeIO;           // Flag: I/O handlers active?
+    bool activeIO;		// Flag: I/O handlers active?
     void _activateIO();         // activate I/O handlers
     void _deactivateIO();       // deactivate I/O handlers
 
@@ -111,9 +109,6 @@ private:
     static void outputReady(AsyncAgent *c);
     static void inputReady(AsyncAgent *c);
     static void errorReady(AsyncAgent *c);
-    static void outputException(AsyncAgent *c);
-    static void inputException(AsyncAgent *c);
-    static void errorException(AsyncAgent *c);
 
 protected:
 
@@ -135,7 +130,7 @@ protected:
 
 public:
     // Constructors
-    LiterateAgent(XtAppContext app_context, char *pth,
+    LiterateAgent(XtAppContext app_context, string pth,
 		  unsigned nTypes = LiterateAgent_NTypes):
 	AsyncAgent(app_context, pth, nTypes), activeIO(false)
     {}
@@ -151,6 +146,12 @@ public:
 	AsyncAgent(app_context, dummy, nTypes), activeIO(false)
     {}
 
+    // Duplicator
+    LiterateAgent(const LiterateAgent& lit)
+	: AsyncAgent(lit), activeIO(lit.activeIO)
+    {}
+    virtual Agent *dup() const { return new LiterateAgent(*this); }
+
     // output data handling
     virtual int write(const char *data, int length);
 
