@@ -1,28 +1,30 @@
-// $Id: PannedGE.h,v 1.2 1995/05/02 09:23:25 zeller Exp $ -*- C++ -*-
+// $Id: PannedGE.h,v 1.6 1997/04/29 17:02:17 zeller Exp $ -*- C++ -*-
 // Panned Graph Editor
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of DDD.
+// This file is part of the DDD Library.
 // 
-// DDD is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public
+// The DDD Library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// DDD is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU General Public License for more details.
+// See the GNU Library General Public License for more details.
 // 
-// You should have received a copy of the GNU General Public
-// License along with DDD -- see the file COPYING.
+// You should have received a copy of the GNU Library General Public
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// DDD is the GDB-based data display debugger.
-// Contact ddd@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
 #ifndef _DDD_PannedGraphEdit_h
 #define _DDD_PannedGraphEdit_h
@@ -34,7 +36,7 @@
 #include "GraphEdit.h"
 
 
-// define any special resource names here that are not in <X11/StringDefs.h>
+// Define any special resource names here that are not in <X11/StringDefs.h>
 
 // Resource names
 
@@ -50,18 +52,21 @@
 #define XtCMaximumScale             "MaximumScale"
 
 
-// declare specific GraphEdit class and instance datatypes
+// Declare specific GraphEdit class and instance datatypes
 typedef struct _PannedGraphEditClassRec *PannedGraphEditWidgetClass;
 typedef struct _PannedGraphEditRec      *PannedGraphEditWidget;
 
-// declare the class constant
+// Declare the class constant
 extern WidgetClass pannedGraphEditWidgetClass;
 
-// declare special access functions
+// Declare special access functions
 
-// create a graph editor with panner; return the graph editor widget ID
+// Create a graph editor with panner; return the graph editor widget ID
 Widget createPannedGraphEdit(Widget parent, String name, ArgList arglist,
 			     Cardinal argcount);
 
+// For a given graph editor W, return its panner
+Widget pannerOfGraphEdit(Widget w);
+
 #endif // _DDD_PannedGraphEdit_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
