@@ -1,32 +1,34 @@
-// $Id: RegionGN.h,v 1.2 1995/05/02 09:23:57 zeller Exp $
+// $Id: RegionGN.h,v 1.12 1997/04/25 06:37:26 zeller Exp $
 // RegionGraphNode class: PosGraphNode with rectangular region
 // centered around position
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_RegionGraphNode_h
-#define _Nora_RegionGraphNode_h
+#ifndef _DDD_RegionGraphNode_h
+#define _DDD_RegionGraphNode_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -41,33 +43,43 @@ public:
     DECLARE_TYPE_INFO
 
 private:
-    BoxRegion _region;		// region
+    BoxRegion _region;		// The region occupied by this node
 
 protected:		
-    // draw region
+    // Draw region
     virtual void forceDraw(Widget w, 
 			   const BoxRegion& exposed, 
 			   const GraphGC& gc) const = 0;
 
-    // center around position
+    // Center around position
     void center();
 
+    // Copy Constructor
+    RegionGraphNode(const RegionGraphNode& node):
+        PosGraphNode(node),
+        _region(node._region)
+    {}
+
 public:
     // Constructor
     RegionGraphNode(const BoxPoint& initialPos = BoxPoint(),
-	const BoxSize& initialSize = NoSize):
+	const BoxSize& initialSize = BoxSize()):
 	PosGraphNode(initialPos),
 	_region(initialPos, initialSize)
     {
 	center();
     }
 
+    // Destructor
+    virtual ~RegionGraphNode() {}
+
     // Move
     virtual void moveTo(const BoxPoint& newPos)
     {
 	PosGraphNode::moveTo(newPos);
 	center();
     }
+
     // Assign new size
     virtual void resize(const BoxSize& newSize)
     {
@@ -85,7 +97,7 @@ public:
 
     // Attributes
     // Region occupied by this node
-    virtual const BoxRegion& region(const GraphGC& gc) const
+    virtual const BoxRegion& region(const GraphGC&) const
     { 
 	return _region; 
     }
@@ -103,4 +115,5 @@ public:
     }
 };
 
-#endif
+#endif // _DDD_RegionGraphNode_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
