@@ -1,4 +1,4 @@
-// $Id: SourceView.h,v 1.58 1997/04/29 22:38:05 zeller Exp $
+// $Id: SourceView.h,v 1.60 1997/05/30 12:24:06 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -120,6 +120,8 @@ class SourceView {
     static void CheckScrollCB(Widget, XtPointer, XtPointer);
     static void CheckScrollWorkProc(XtPointer, XtIntervalId *);
 
+    static void InhibitModificationCB      (Widget, XtPointer, XtPointer);
+
     static void StackDialogPoppedDownCB    (Widget, XtPointer, XtPointer);
     static void CodeDialogPoppedDownCB     (Widget, XtPointer, XtPointer);
     static void RegisterDialogPoppedDownCB (Widget, XtPointer, XtPointer);
@@ -198,6 +200,9 @@ class SourceView {
     static MMDesc text_popup[];
     static MMDesc bp_area[];
 
+    static void set_text_popup_label(int item, const string& arg, bool sens);
+    static void set_text_popup_resource(int item, const string& arg);
+
     //-----------------------------------------------------------------------
     // Daten
     //-----------------------------------------------------------------------
