@@ -1,3 +1,5 @@
+ICE_CHECK_DECL(asctime, time.h)
+ICE_CHECK_DECL(difftime, time.h)
 ICE_CHECK_DECL(dup2, unistd.h)
 ICE_CHECK_DECL(endpwent, pwd.h)
 ICE_CHECK_DECL(fcntl, fcntl.h)
@@ -12,10 +14,12 @@ ICE_CHECK_DECL(grantpt, stdlib.h)
 ICE_CHECK_DECL(ioctl, unistd.h)
 ICE_CHECK_DECL(lstat, sys/stat.h)
 ICE_CHECK_DECL(malloc, stdlib.h)
-ICE_CHECK_DECL(memset, string.h memory.h)
+ICE_CHECK_DECL(memcpy, string.h)
+ICE_CHECK_DECL(memset, string.h)
 ICE_CHECK_DECL(popen, stdio.h)
 ICE_CHECK_DECL(pclose, stdio.h)
 ICE_CHECK_DECL(ptsname, stdlib.h)
+ICE_CHECK_DECL(raise, signal.h)
 ICE_CHECK_DECL(rand, stdlib.h)
 ICE_CHECK_DECL(random, stdlib.h)
 ICE_CHECK_DECL(readlink, unistd.h)
@@ -34,6 +38,7 @@ ICE_CHECK_DECL(srand, stdlib.h)
 ICE_CHECK_DECL(srandom, stdlib.h)
 ICE_CHECK_DECL(stat, sys/stat.h)
 ICE_CHECK_DECL(strerror, string.h)
+ICE_CHECK_DECL(strftime, time.h)
 ICE_CHECK_DECL(strsignal, string.h)
 ICE_CHECK_DECL(strtol, stdlib.h)
 ICE_CHECK_DECL(strtod, stdlib.h)
